"use strict";
this.name = "oolite-tianve";
this.author = "Drew Wagar and Contributions by Commander McLane and phkb";
this.copyright = "© 2009 Drew Wagar.";
this.description = "Makeover for the Tianve Star System in Chart One";
this.version = "2.0";

this._posVE;
this._massLocker = null;
this._always = false;

//-------------------------------------------------------------------------------------------------------------
this.startUpComplete = function () {
	var vx = worldScripts.VimanaX_HUD;
	if (vx) {
		// update vimana to use a different model to the original
		vx._gameShips["Tianve Pulsar Monitoring Station"] = "octahedron";
		vx._gameShips["The Pulsar Monitoring Station"] = "octahedron";
		vx._gameShips["Vampire Mk1.5 : Rebecca Weston"] = "vampiremk1";
		vx._gameShips["Tianve Billboard"] = "billboard";
		vx._gameShips["Tourist StarLiner - 'Join us next time, Commander!'"] = "boa_cruiser";
		vx._gameShips["Tourist StarLiner - 'Seats Available, Commander!'"] = "boa_cruiser";
	}
}

//-------------------------------------------------------------------------------------------------------------
this.turnStationToEntity = function (station, entity) {
	var targetVector = entity.position.subtract(station.position).direction();
	station.orientation = targetVector.rotationTo([0, 0, 1]);
}

//-------------------------------------------------------------------------------------------------------------
this.systemWillPopulate = function () {

	worldScripts["oolite-tianve"]._posVE = null;

	if (galaxyNumber === 0 && system.ID === 246 || this._always == true) {
		var stationPos = Vector3D(-528000, 137500, 819000).fromCoordinateSystem("pwm");
		system.setPopulator("tianve_pulsar_station", {
			callback: function (pos) {
				//var moon = system.addMoon("tianve_pulsar");
				var pl = Vector3D(-537000, 138000, 1011250).fromCoordinateSystem("pwm")
				worldScripts["oolite-tianve"]._posVE = pl; //moon.position;
				var ve = system.addVisualEffect("tianve_pulsar_flashers", worldScripts["oolite-tianve"]._posVE);
				ve.orientation = system.mainPlanet.orientation;
				
				var stn = system.addShips("[tianve-pulsar-station]", 1, pos, 0)[0];
				worldScripts["oolite-tianve"].turnStationToEntity(stn, ve);

				system.addShips("tianve-liner-moving", 1, Vector3D(14500, 80500, 28500).fromCoordinateSystem("pwm"));
				system.addShips("tianve-small-billboard-01", 1, Vector3D(14500, 81500, 28000).fromCoordinateSystem("pwm"));
				system.addShips("tianve-liner-motionless", 1, Vector3D(16000, 82000, 28000).fromCoordinateSystem("pwm"));

				// At the Witchpoint Marker

				system.addShips("tianve-small-billboard-01", 1, Vector3D(-2500, 2500, 442500).fromCoordinateSystem("pwm"));
				system.addShips("tianve-liner-moving", 1, Vector3D(-3500, 3500, 442500).fromCoordinateSystem("pwm"));

				// Halfway between the Main Station and the Pulsar

				system.addShips("tianve-liner-moving", 1, Vector3D(-267000, 112500, 523500).fromCoordinateSystem("pwm"));
				system.addShips("tianve-small-billboard-02", 1, Vector3D(-267000, 112500, 523500).fromCoordinateSystem("pwm"));

				// At the Pulsar

				system.addShips("tianve-liner-moving", 2, Vector3D(-528000, 137500, 819000).fromCoordinateSystem("pwm"));
				system.addShips("tianve-small-billboard-03", 1, Vector3D(-521500, 137000, 807500).fromCoordinateSystem("pwm"));
				system.addShips("tianve-rebecca", 1, Vector3D(-528000, 147500, 819000).fromCoordinateSystem("pwm"));
			},
			location: "COORDINATES",
			coordinates: stationPos,
			deterministic: true
		});
	}
}

//-------------------------------------------------------------------------------------------------------------
this.shipLaunchedFromStation = function (launchStation) {
	if (launchStation == system.mainStation && system.ID == 246 && galaxyNumber == 0) {
		launchStation.commsMessage("Don't forget to visit the Pulsar whilst you're here, Commander!", player.ship);
	}
	this.$startTimer();
}

//-------------------------------------------------------------------------------------------------------------
this.shipExitedWitchspace = function () {
	this.$startTimer();
	if (system.ID == 246 && galaxyNumber == 0) {
		player.consoleMessage("Welcome to %H! To visit the Pulsar, select 'P' on your advanced space compass, Commander!", 5);
	}
}

//-------------------------------------------------------------------------------------------------------------
this.playerBoughtEquipment = function (equipmentKey) {
	if (equipmentKey === "EQ_TIANVE_STICKER") {
		mission.setInstructionsKey("tianve_sticker");
		player.ship.removeEquipment("EQ_TIANVE_STICKER");
	}
}

//-------------------------------------------------------------------------------------------------------------
this.$startTimer = function() {
	if (this._timer && this._timer.isRunning) this._timer.stop();
	if (this._posVE) {
		this._timer = new Timer(this, this.$checkPosition, 0.5, 0.5);
	}
}

//-------------------------------------------------------------------------------------------------------------
this.$checkPosition = function $checkPosition() {
	if (!this._posVE) {
		this._timer.stop();
		return;
	}
	var p = player.ship;
	var dist = p.position.distanceTo(this._posVE);
	if (dist < 159200) {
		p.temperature += 0.05;
	}
	if (dist < 160000 && !this.masslocker) {
		this.masslocker = system.addShips("tianve-masslocker", 1, player.ship.position.add(player.ship.vectorUp.multiply(300)))[0];
	}
	if (dist >= 160000 && this.masslocker) {
		this.masslocker.remove(true);
		this.masslocker = null;
	}
}
